Response

Struct Response 

pub struct Response {
    pub status: i32,
    pub body: String,
    pub headers: String,
}

Fields

status: i32body: Stringheaders: String

Implementations

Source

impl Response

pub fn set_status(&mut self, status: i32)

Set response-status

Example

res.set_status(404);
pub fn get_status(&self) -> i32

Get response-status

Example

res.get_status();
pub fn send_body(&mut self, body: &str)

Send response-body as text

Example

res.send_body("body content");
pub fn send_file(&mut self, path: &str)

Send response-body as file

Example

res.send_file("path.html");
pub fn get_body(&self) -> String

Get response-body

Example

res.get_body();
pub fn set_header(&mut self, headers: &HashMap<&str, &str>)

Send response-headers in the form of a hashmap (this will overwrite an already set header for the response)

Example

let mut headers: HashMap<&str, &str> = HashMap::new();
 
headers.insert("key", "value");
 
res.set_header(&headers);
pub fn append_header(&mut self, headers: &HashMap<&str, &str>)

Append response-headers in the form of a hashmap (this will append to the already set header for the response)

Example

let mut headers: HashMap<&str, &str> = HashMap::new();
 
headers.insert("key", "value");
 
res.append_header(&headers);
pub fn clear_header(&mut self)

Clear set response-header

Example

res.clear_header();
pub fn set_string_header(&mut self, header: String)

Set response-header in the form of a string (this will overwrite an already set header for the response)

Example

res.set_string_header("Key: Value");
pub fn append_string_header(&mut self, header: String)

Append response-header in the form of a string (this will append to the already set header for the response)

Example

res.append_string_header("Key: Value");
pub fn get_header(&self) -> String

Get response-header

Example

res.get_header();
pub fn redirect(&mut self, path: &str)

Redirects to given path

Example

res.redirect("/path");